@@ -13,7 +13,7 @@ class LazyLoadBalancingInfomrationDict(LazyImmutableDict):
     # This is the mechanism I found suitable:
     # On the first call to the dict, it fetches the key and values from WMI and uses them from here on
     def __init__(self, wmi_client):
-        # this (skipping the __init__ of LazyImmutableDict is on purpose 
+        # this (skipping the __init__ of LazyImmutableDict is on purpose
         super(LazyImmutableDict, self).__init__()
         self.wmi_client = wmi_client
 
@@ -133,7 +133,11 @@ class WindowsPath(multipath.Path):
     def get_hctl(self):
         from infi.dtypes.hctl import HCTL
         scsi_address = self._pdo_information.ScsiAddress
-        return HCTL(scsi_address.PortNumber, scsi_address.ScsiPathId, scsi_address.TargetId, scsi_address.Lun)
+        try:
+            return HCTL(scsi_address.PortNumber, scsi_address.ScsiPathId, scsi_address.TargetId, scsi_address.Lun)
+        except AttributeError:
+            # we lost a PDO
+            raise RescanIsNeeded()
 
     @cached_method
     def get_state(self):
@@ -152,4 +156,4 @@ class WindowsPath(multipath.Path):
         return multipath.PathStatistics(path_perfromance.BytesRead,
                                         path_perfromance.BytesWritten,
                                         path_perfromance.NumberReads,
-                                        path_perfromance.NumberWrites)
\ No newline at end of file
+                                        path_perfromance.NumberWrites)
