@@ -30,13 +30,13 @@ class ModelTestCase(unittest.TestCase):
         self.assertGreater(device.get_size_in_bytes(), 0)
         self.assertIsInstance(device.get_hctl(), HCTL)
         self.assertTrue(device.get_display_name().startswith("PHYSICALDRIVE"))
-        self.assertIsInstance(device.get_block_access_path(), unicode)
-        self.assertIsInstance(device.get_scsi_access_path(), unicode)
-        self.assertIsInstance(device.get_scsi_vendor_id(), str)
-        self.assertIsInstance(device.get_scsi_product_id(), str)
+        self.assertIsInstance(device.get_block_access_path(), basestring)
+        self.assertIsInstance(device.get_scsi_access_path(), basestring)
+        self.assertIsInstance(device.get_scsi_vendor_id(), basestring)
+        self.assertIsInstance(device.get_scsi_product_id(), basestring)
         self.assertEqual(device.get_scsi_vid_pid(), (device.get_scsi_vendor_id(), device.get_scsi_product_id()))
         _ = device.get_scsi_inquiry_pages()
-        self.assertIsInstance(device.get_scsi_serial_number(), str)
+        self.assertIsInstance(device.get_scsi_serial_number(), basestring)
         _ = device.get_scsi_standard_inquiry()
         self._assert_connectivity(device)
 
@@ -65,12 +65,12 @@ class ModelTestCase(unittest.TestCase):
     def _assert_multipath_device(self, device):
         self.assertGreater(device.get_size_in_bytes(), 0)
         self.assertTrue(device.get_display_name().startswith("PHYSICALDRIVE"))
-        self.assertIsInstance(device.get_block_access_path(), unicode)
-        self.assertIsInstance(device.get_scsi_vendor_id(), str)
-        self.assertIsInstance(device.get_scsi_product_id(), str)
+        self.assertIsInstance(device.get_block_access_path(), basestring)
+        self.assertIsInstance(device.get_scsi_vendor_id(), basestring)
+        self.assertIsInstance(device.get_scsi_product_id(), basestring)
         self.assertEqual(device.get_scsi_vid_pid(), (device.get_scsi_vendor_id(), device.get_scsi_product_id()))
         _ = device.get_scsi_inquiry_pages()
-        self.assertIsInstance(device.get_scsi_serial_number(), str)
+        self.assertIsInstance(device.get_scsi_serial_number(), basestring)
         _ = device.get_scsi_standard_inquiry()
         from infi.dtypes.hctl import HCTL
         for path in device.get_paths():
